Ralph Scrooge
-------------

What is Scrooge? The simple answer for this question is: it is a "billing system for corporations". How does it work? It distributes costs of equipment, electricity, network, etc. to clients. For example, if you are COO or the chief accountant at a big company with numerous assets, projects and people, you probably need to know how many resources is used by each team or employee. Maybe you need to charge some people with these costs or just need financial statements to make an important decision. No matter why you need this information, you can obtain it from Scrooge. However, the first thing you need to know is that Scrooge is neither an Excel file nor an advanced calculator – it works on data collected from many devices or supplied by many people. It is a system to calculate and display results with many additional features that make it easier to use.


.. toctree::
   :maxdepth: 3

   overview
   installation
   configuration
   tutorial
   reports
   servicesandusages
   plugins
   costs
   api
   statements
